@@ -118,14 +118,17 @@ describe 'designate' do
         :rabbit_ha_queues                => '<SERVICE DEFAULT>',
         :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
         :heartbeat_rate                  => '<SERVICE DEFAULT>',
-        :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
         :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
         :amqp_durable_queues             => '<SERVICE DEFAULT>',
+        :amqp_auto_delete                => '<SERVICE DEFAULT>',
         :rabbit_quorum_queue             => '<SERVICE DEFAULT>',
         :rabbit_transient_quorum_queue   => '<SERVICE DEFAULT>',
+        :rabbit_transient_queues_ttl     => '<SERVICE DEFAULT>',
         :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+        :use_queue_manager               => '<SERVICE DEFAULT>',
+        :rabbit_stream_fanout            => '<SERVICE DEFAULT>',
         :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
       )
     end
@@ -139,13 +142,15 @@ describe 'designate' do
         :rabbit_ha_queues                   => true,
         :rabbit_heartbeat_timeout_threshold => '60',
         :rabbit_heartbeat_rate              => '10',
-        :rabbit_heartbeat_in_pthread        => true,
         :rabbit_qos_prefetch_count          => 0,
         :rabbit_quorum_queue                => true,
         :rabbit_transient_quorum_queue      => true,
+        :rabbit_transient_queues_ttl        => 60,
         :rabbit_quorum_delivery_limit       => 3,
         :rabbit_quorum_max_memory_length    => 5,
         :rabbit_quorum_max_memory_bytes     => 1073741824,
+        :rabbit_use_queue_manager           => true,
+        :rabbit_stream_fanout               => true,
         :rabbit_enable_cancel_on_failover   => false,
         :kombu_reconnect_delay              => '1.0',
         :kombu_failover_strategy            => 'shuffle',
@@ -159,13 +164,15 @@ describe 'designate' do
       :rabbit_ha_queues                => true,
       :heartbeat_timeout_threshold     => '60',
       :heartbeat_rate                  => '10',
-      :heartbeat_in_pthread            => true,
       :rabbit_qos_prefetch_count       => 0,
       :rabbit_quorum_queue             => true,
       :rabbit_transient_quorum_queue   => true,
+      :rabbit_transient_queues_ttl     => 60,
       :rabbit_quorum_delivery_limit    => 3,
       :rabbit_quorum_max_memory_length => 5,
       :rabbit_quorum_max_memory_bytes  => 1073741824,
+      :use_queue_manager               => true,
+      :rabbit_stream_fanout            => true,
       :enable_cancel_on_failover       => false,
       :kombu_reconnect_delay           => '1.0',
       :kombu_failover_strategy         => 'shuffle'
