@@ -15,6 +15,7 @@ describe 'designate::keystone::auth' do
         :configure_user      => true,
         :configure_user_role => true,
         :configure_endpoint  => true,
+        :configure_service   => true,
         :service_name        => 'designate',
         :service_type        => 'dns',
         :service_description => 'OpenStack DNS Service',
@@ -23,7 +24,7 @@ describe 'designate::keystone::auth' do
         :password            => 'designate_password',
         :email               => 'designate@localhost',
         :tenant              => 'services',
-        :roles               => ['admin'],
+        :roles               => ['admin', 'service'],
         :system_scope        => 'all',
         :system_roles        => [],
         :public_url          => 'http://127.0.0.1:9001',
@@ -38,12 +39,13 @@ describe 'designate::keystone::auth' do
           :auth_name           => 'alt_designate',
           :email               => 'alt_designate@alt_localhost',
           :tenant              => 'alt_service',
-          :roles               => ['admin', 'service'],
+          :roles               => ['admin'],
           :system_scope        => 'alt_all',
           :system_roles        => ['admin', 'member', 'reader'],
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
+          :configure_service   => false,
           :service_description => 'Alternative OpenStack DNS Service',
           :service_name        => 'alt_service',
           :service_type        => 'alt_dns',
@@ -57,6 +59,7 @@ describe 'designate::keystone::auth' do
         :configure_user      => false,
         :configure_user_role => false,
         :configure_endpoint  => false,
+        :configure_service   => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_dns',
         :service_description => 'Alternative OpenStack DNS Service',
@@ -65,7 +68,7 @@ describe 'designate::keystone::auth' do
         :password            => 'designate_password',
         :email               => 'alt_designate@alt_localhost',
         :tenant              => 'alt_service',
-        :roles               => ['admin', 'service'],
+        :roles               => ['admin'],
         :system_scope        => 'alt_all',
         :system_roles        => ['admin', 'member', 'reader'],
         :public_url          => 'https://10.10.10.10:80',
